<?php
// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Connect to the SQLite database
$db = new SQLite3('./api/database.db');

// Function to delete a single file and its database record
function deleteFile($fileId, $db) {
    // Fetch the file details from the database
    $stmt = $db->prepare("SELECT * FROM apks WHERE id = :id");
    $stmt->bindValue(':id', $fileId, SQLITE3_INTEGER);
    $result = $stmt->execute();
    $file = $result->fetchArray(SQLITE3_ASSOC);

    if ($file) {
        // Get the file path
        $filePath = __DIR__ . '/uploads/' . basename($file['file_path']); // Use basename to ensure no path traversal

        // Check if the file exists and delete it from the uploads folder
        if (file_exists($filePath)) {
            if (unlink($filePath)) {
                echo "File deleted successfully from the server.<br>";
            } else {
                echo "Failed to delete the file from the server. Check permissions.<br>";
            }
        } else {
            echo "File not found on the server. Path was: " . htmlspecialchars($filePath) . "<br>";
        }

        // Delete the file record from the database
        $stmt = $db->prepare("DELETE FROM apks WHERE id = :id");
        $stmt->bindValue(':id', $fileId, SQLITE3_INTEGER);
        if ($stmt->execute()) {
            echo "Record deleted successfully from the database.<br>";
        } else {
            echo "Failed to delete the record from the database.<br>";
        }
    } else {
        echo "File not found in the database.<br>";
    }
}

// Handle single file deletion
if (isset($_GET['delete'])) {
    $fileId = intval($_GET['delete']);  // Ensure the file ID is an integer
    deleteFile($fileId, $db);

    // Redirect back to the main page after deletion
    header("Location: index.php");
    exit();
}

// Handle delete all files
if (isset($_POST['delete_all'])) {
    // Fetch all files from the database
    $result = $db->query("SELECT id FROM apks");
    while ($file = $result->fetchArray(SQLITE3_ASSOC)) {
        deleteFile($file['id'], $db);
    }

    // Redirect back to the main page after deletion
    header("Location: index.php");
    exit();
}

// Close the database connection
$db->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>File Management</title>
</head>
<body>

<h2>Uploaded Files</h2>
<ul>
    <?php
    // Reconnect to the database to list files
    $db = new SQLite3('./api/.database.db');
    $result = $db->query("SELECT * FROM apks");
    while ($file = $result->fetchArray(SQLITE3_ASSOC)) {
        echo "<li>" . htmlspecialchars($file['name']) . " - <a href='?delete=" . $file['id'] . "'>Delete</a></li>";
    }
    $db->close();
    ?>
</ul>

<!-- Form to delete all files -->
<form method="POST">
    <button type="submit" name="delete_all" onclick="return confirm('Are you sure you want to delete all files?');">Delete All Files</button>
</form>

</body>
</html>
