<?php
session_start();

// Database configuration
$dbDir = __DIR__ . '/api';
if (!file_exists($dbDir)) {
    mkdir($dbDir, 0744, true);
}

$dbPath = $dbDir . '/database.db';

try {
    $db = new SQLite3($dbPath);
    $db->enableExceptions(true);
} catch (Exception $e) {
    die('Database Error: ' . $e->getMessage());
}

// Create tables
$db->exec("CREATE TABLE IF NOT EXISTS credentials (id INTEGER PRIMARY KEY, username TEXT, password TEXT)");
$db->exec("CREATE TABLE IF NOT EXISTS apks (id INTEGER PRIMARY KEY, name TEXT, file_path TEXT)");

// Initial setup check
$credResult = $db->query("SELECT * FROM credentials WHERE id = 1");
$credentials = $credResult->fetchArray(SQLITE3_ASSOC);

// Handle initial setup
if (!$credentials) {
    if (isset($_POST['setupCredentials'])) {
        $newUsername = trim($_POST['newUsername']);
        $newPassword = trim($_POST['newPassword']);
        
        if (!empty($newUsername) && !empty($newPassword)) {
            try {
                $stmt = $db->prepare("INSERT INTO credentials (id, username, password) VALUES (1, ?, ?)");
                $stmt->bindValue(1, $newUsername, SQLITE3_TEXT);
                $stmt->bindValue(2, $newPassword, SQLITE3_TEXT);
                $stmt->execute();
                $_SESSION['loggedin'] = true;
                header('Location: index.php');
                exit();
            } catch (Exception $e) {
                $error = "Setup failed: " . $e->getMessage();
            }
        } else {
            $error = "Both fields are required";
        }
    }
    ?>
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <title>Initial Setup</title>
        <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
        <style>
            :root {
                --black-3d: linear-gradient(145deg, #2a2a2a, #1a1a1a);
                --btn-shadow: 3px 3px 5px rgba(0,0,0,0.2), 
                            -1px -1px 3px rgba(255,255,255,0.1);
                --btn-active: inset 2px 2px 4px rgba(0,0,0,0.2), 
                            inset -1px -1px 3px rgba(255,255,255,0.1);
            }
            body {
                background: #1a1a1a;
                min-height: 100vh;
                display: flex;
                align-items: center;
            }
            .setup-card {
                background: var(--black-3d);
                border-radius: 15px;
                box-shadow: var(--btn-shadow);
                border: none;
            }
            .btn-3d {
                background: var(--black-3d);
                color: #fff !important;
                border: none;
                border-radius: 10px;
                box-shadow: var(--btn-shadow);
                transition: all 0.2s;
            }
            .btn-3d:hover {
                transform: translateY(-2px);
                box-shadow: 4px 4px 6px rgba(0,0,0,0.3), 
                          -2px -2px 4px rgba(255,255,255,0.1);
            }
            .btn-3d:active {
                transform: translateY(0);
                box-shadow: var(--btn-active);
            }
        </style>
    </head>
    <body>
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-md-6">
                    <div class="card setup-card text-white p-4">
                        <h2 class="text-center mb-4">Initial Setup</h2>
                        <?php if(isset($error)): ?>
                            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
                        <?php endif; ?>
                        <form method="post">
                            <div class="form-group">
                                <label>Admin Username</label>
                                <input type="text" name="newUsername" class="form-control bg-dark text-white" required>
                            </div>
                            <div class="form-group">
                                <label>Admin Password</label>
                                <input type="password" name="newPassword" class="form-control bg-dark text-white" required>
                            </div>
                            <button type="submit" name="setupCredentials" class="btn btn-3d btn-block py-2">
                                Complete Setup
                            </button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </body>
    </html>
    <?php
    exit();
}

// Handle login
if (isset($_POST['login'])) {
    $username = trim($_POST['username']);
    $password = trim($_POST['password']);
    
    try {
        $stmt = $db->prepare("SELECT * FROM credentials WHERE username = ? AND password = ?");
        $stmt->bindValue(1, $username, SQLITE3_TEXT);
        $stmt->bindValue(2, $password, SQLITE3_TEXT);
        $result = $stmt->execute();
        
        if ($result->fetchArray()) {
            $_SESSION['loggedin'] = true;
            header('Location: index.php');
            exit();
        } else {
            $error = "Invalid credentials";
        }
    } catch (Exception $e) {
        $error = "Login error: " . $e->getMessage();
    }
}

// Handle logout
if (isset($_GET['logout'])) {
    session_destroy();
    header('Location: index.php');
    exit();
}

// Handle credentials update
if (isset($_POST['updateCredentials'])) {
    $newUsername = trim($_POST['newUsername']);
    $newPassword = trim($_POST['newPassword']);
    
    try {
        $stmt = $db->prepare("UPDATE credentials SET username = ?, password = ? WHERE id = 1");
        $stmt->bindValue(1, $newUsername, SQLITE3_TEXT);
        $stmt->bindValue(2, $newPassword, SQLITE3_TEXT);
        $stmt->execute();
        $success = "Credentials updated!";
    } catch (Exception $e) {
        $error = "Update failed: " . $e->getMessage();
    }
}

// Fetch current credentials
$credResult = $db->query("SELECT * FROM credentials WHERE id = 1");
$credentials = $credResult->fetchArray(SQLITE3_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>File Manager</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.9.2/min/dropzone.min.css">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.9.2/min/dropzone.min.js"></script>
    <style>
        :root {
            --black-3d: linear-gradient(145deg, #2a2a2a, #1a1a1a);
            --btn-shadow: 3px 3px 5px rgba(0,0,0,0.2), 
                        -1px -1px 3px rgba(255,255,255,0.1);
            --btn-active: inset 2px 2px 4px rgba(0,0,0,0.2), 
                        inset -1px -1px 3px rgba(255,255,255,0.1);
            --accent: #007bff;
        }
        body {
            background: #1a1a1a;
            color: #fff;
            min-height: 100vh;
        }
        .btn-3d {
            background: var(--black-3d);
            color: #fff !important;
            border: none;
            border-radius: 10px;
            box-shadow: var(--btn-shadow);
            transition: all 0.2s;
        }
        .btn-3d:hover {
            transform: translateY(-2px);
            box-shadow: 4px 4px 6px rgba(0,0,0,0.3), 
                      -2px -2px 4px rgba(255,255,255,0.1);
        }
        .btn-3d:active {
            transform: translateY(0);
            box-shadow: var(--btn-active);
        }
        .contact-btn {
            position: fixed;
            bottom: 20px;
            right: 20px;
            z-index: 1000;
            padding: 12px 25px;
        }
        .card-3d {
            background: var(--black-3d);
            border-radius: 15px;
            box-shadow: var(--btn-shadow);
            border: none;
        }
        .dropzone {
            background: rgba(0,0,0,0.3);
            border: 2px dashed rgba(255,255,255,0.2);
            border-radius: 10px;
            color: #aaa;
        }
        .dz-message {
            font-size: 1.2rem;
        }
    </style>
</head>
<body>
    <!-- Contact Button -->
    <a href="https://t.me/BA1N5" class="btn btn-3d contact-btn" target="_blank">
        Contact Me
    </a>

    <div class="container py-5">
        <?php if (!isset($_SESSION['loggedin'])): ?>
            <!-- Login Form -->
            <div class="row justify-content-center">
                <div class="col-md-6">
                    <div class="card card-3d p-4">
                        <h2 class="text-center mb-4">Login</h2>
                        <?php if(isset($error)): ?>
                            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
                        <?php endif; ?>
                        <form method="post">
                            <div class="form-group">
                                <label>Username</label>
                                <input type="text" name="username" class="form-control bg-dark text-white" required>
                            </div>
                            <div class="form-group">
                                <label>Password</label>
                                <input type="password" name="password" class="form-control bg-dark text-white" required>
                            </div>
                            <button type="submit" name="login" class="btn btn-3d btn-block py-2">
                                Sign In
                            </button>
                        </form>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <!-- Main Interface -->
            <div class="d-flex justify-content-between align-items-center mb-5">
                <h1 class="text-light">File Manager</h1>
                <a href="?logout=true" class="btn btn-3d px-4">Logout</a>
            </div>

           <!-- Control Buttons -->
<div class="row mb-4">
    <div class="col-md-3 mb-3">
        <a href="https://aftv.news" class="btn btn-3d btn-block py-3" target="_self">
            Downloader
        </a>
    </div>
    <div class="col-md-3 mb-3">
        <a href="https://tinyurl.com/" class="btn btn-3d btn-block py-3" target="_blank">
            TinyURL
        </a>
    </div>
    <div class="col-md-3 mb-3">
        <button onclick="toggleCredentials()" class="btn btn-3d btn-block py-3">
            Update Credentials
        </button>
    </div>
</div>

            <!-- Credentials Update -->
            <div id="credentialsForm" class="card card-3d mb-5" style="display: none;">
                <div class="card-body">
                    <?php if(isset($success)): ?>
                        <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
                    <?php endif; ?>
                    <?php if(isset($error)): ?>
                        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
                    <?php endif; ?>
                    <form method="post">
                        <div class="form-group">
                            <label>New Username</label>
                            <input type="text" name="newUsername" class="form-control bg-dark text-white" 
                                   value="<?= htmlspecialchars($credentials['username']) ?>" required>
                        </div>
                        <div class="form-group">
                            <label>New Password</label>
                            <input type="password" name="newPassword" class="form-control bg-dark text-white" 
                                   value="<?= htmlspecialchars($credentials['password']) ?>" required>
                        </div>
                        <button type="submit" name="updateCredentials" class="btn btn-3d px-5">
                            Update
                        </button>
                    </form>
                </div>
            </div>

            <!-- File Upload -->
            <div class="card card-3d mb-5">
                <div class="card-body">
                    <form action="upload_config.php" class="dropzone" id="my-awesome-dropzone"></form>
                </div>
            </div>

            <!-- File List -->
            <div class="card card-3d">
                <div class="card-body p-0">
                    <div class="table-responsive">
                        <table class="table table-dark mb-0">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>File Name</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                $result = $db->query("SELECT * FROM apks ORDER BY id DESC");
                                while ($row = $result->fetchArray(SQLITE3_ASSOC)): ?>
                                    <tr>
                                        <td><?= $row['id'] ?></td>
                                        <td><?= htmlspecialchars($row['name']) ?></td>
                                        <td>
                                            <button class="btn btn-3d btn-sm copy-btn" 
                                                    data-clipboard-text="<?= htmlspecialchars($row['file_path']) ?>">
                                                Copy Link
                                            </button>
                                            <a href="delete_file.php?delete=<?= $row['id'] ?>" 
                                               class="btn btn-3d btn-sm btn-danger"
                                               onclick="return confirm('Delete this file permanently?')">
                                                Delete
                                            </a>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/clipboard.js/2.0.6/clipboard.min.js"></script>
    <script>
    // Dropzone Configuration
    Dropzone.options.myAwesomeDropzone = {
        url: "upload_config.php",
        paramName: "file",
        maxFilesize: 1024, // 1GB
        chunking: true,
        forceChunking: true,
        chunkSize: 10 * 1024 * 1024, // 10MB chunks
        parallelUploads: 4,
        retryChunks: true,
        retryChunksLimit: 3,
        init: function() {
            this.on("complete", function() {
                if (!this.getUploadingFiles().length) {
                    window.location.reload();
                }
            });
        }
    };

    // Clipboard
    new ClipboardJS('.copy-btn');

    // Toggle Credentials Form
    function toggleCredentials() {
        const form = document.getElementById('credentialsForm');
        form.style.display = form.style.display === 'none' ? 'block' : 'none';
    }

    // Tooltips
    $(document).ready(function(){
        $('.copy-btn').tooltip({
            trigger: 'click',
            title: 'Copied!',
            placement: 'top'
        });
    });
    </script>
</body>
</html>