<?php
// Database connection
$db = new SQLite3('./api/database.db');

// Handle file uploads
if (!empty($_FILES)) {
    $uploadDir = __DIR__ . '/uploads/';
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0777, true);
    }

    // Process chunked uploads
    $chunk = isset($_POST["dzchunkindex"]) ? intval($_POST["dzchunkindex"]) : 0;
    $totalChunks = isset($_POST["dztotalchunkcount"]) ? intval($_POST["dztotalchunkcount"]) : 0;
    $fileName = $_FILES["file"]["name"];
    $fileName = str_replace('+', ' ', $fileName); // Fix for '+' encoding issue
    $filePath = $uploadDir . $fileName;

    // Save the chunk
    $chunkFile = $filePath . ".part" . $chunk;
    move_uploaded_file($_FILES["file"]["tmp_name"], $chunkFile);

    // If last chunk, assemble the file
    if ($chunk === $totalChunks - 1) {
        $fp = fopen($filePath, "w");
        for ($i = 0; $i < $totalChunks; $i++) {
            $chunkFile = $filePath . ".part" . $i;
            $chunkContent = file_get_contents($chunkFile);
            fwrite($fp, $chunkContent);
            unlink($chunkFile); // Remove the chunk
        }
        fclose($fp);

        // Construct the full URL of the uploaded file dynamically
        $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
        $basePath = rtrim(dirname($_SERVER['PHP_SELF']), '/\\') . "/uploads/";
        $fullUrl = $protocol . $_SERVER['HTTP_HOST'] . $basePath . rawurlencode($fileName);

        // Insert file details into the database
        $stmt = $db->prepare("INSERT INTO apks (name, file_path) VALUES (:name, :path)");
        $stmt->bindValue(':name', $fileName, SQLITE3_TEXT);
        $stmt->bindValue(':path', $fullUrl, SQLITE3_TEXT);
        $stmt->execute();
    }

    echo "File uploaded successfully!";
} else {
    echo "No file uploaded.";
}

// Function to delete a specific file and its database record (if exists)
function deleteFile($fileName) {
    global $db;

    $uploadDir = __DIR__ . '/uploads/';
    $filePath = $uploadDir . $fileName;

    // Delete the file from the directory
    if (file_exists($filePath)) {
        if (unlink($filePath)) {
            echo "File '$fileName' deleted successfully!";
        } else {
            echo "Failed to delete the file '$fileName'.";
        }
    } else {
        echo "File '$fileName' does not exist.";
    }

    // Delete the file record from the database
    $stmt = $db->prepare("DELETE FROM apks WHERE name = ?");
    $stmt->bindValue(1, $fileName, SQLITE3_TEXT);
    $stmt->execute();
}

// Display all files from the uploads folder
function displayAllFiles() {
    global $db;
    $uploadDir = __DIR__ . '/uploads/';
    $files = array_diff(scandir($uploadDir), array('.', '..'));

    echo "<table class='table table-striped table-sm'>";
    echo "<thead><tr><th>Name</th><th>File Path</th><th>Delete</th></tr></thead><tbody>";

    foreach ($files as $file) {
        $filePath = $uploadDir . $file;
        if (is_file($filePath)) {
            $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
            $basePath = rtrim(dirname($_SERVER['PHP_SELF']), '/\\') . "/uploads/";
            $fullUrl = $protocol . $_SERVER['HTTP_HOST'] . $basePath . rawurlencode($file);
            
            echo "<tr>";
            echo "<td>$file</td>";
            echo "<td><a href='$fullUrl' target='_blank'>$fullUrl</a></td>";
            echo "<td><a href='?delete=" . urlencode($file) . "' class='btn btn-danger'>Delete</a></td>";
            echo "</tr>";
        }
    }

    echo "</tbody></table>";
}

// Handle delete request via GET
if (isset($_GET['delete'])) {
    $fileName = $_GET['delete'];
    deleteFile($fileName);
    echo "<script>window.location.href='" . basename($_SERVER["SCRIPT_NAME"]) . "?status=2'</script>";
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Upload and Manage Files</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <style>
        body {
            background-color: #2f2f2f;
            color: #e0e0e0;
        }
        .table {
            background-color: #3b3b3b;
        }
        .btn-danger {
            background: linear-gradient(145deg, #e63946, #900d0d);
            border: none;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2 class="text-center text-white">File Management</h2>
        <form action="" class="dropzone" id="my-awesome-dropzone" method="post" enctype="multipart/form-data">
            <div class="dz-message needsclick" style="color: #ccc;">
                Drop files here or click to upload<br>
                <small class="text-muted">(Maximum file size: 256MB)</small>
            </div>
        </form>

        <!-- Display all uploaded files -->
        <div class="mt-4">
            <?php displayAllFiles(); ?>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.9.2/min/dropzone.min.js"></script>
    <script>
    // Dropzone configuration
    Dropzone.options.myAwesomeDropzone = {
        url: "upload.php",
        paramName: "file",
        maxFilesize: 256,
        chunking: true,
        forceChunking: true,
        chunkSize: 2000000,
        parallelUploads: 1,
        retryChunks: true,
        retryChunksLimit: 3,
        init: function() {
            this.on("success", function() {
                window.location.reload();
            });
        }
    };
    </script>
</body>
</html>